%define lib_major	10
%define lib_name	%mklibname input %{lib_major}
%define develname	%mklibname -d input

Name:		libinput
Version:        1.23.0
Release:	%mkrel 2
Summary:	Input device library
License:	MIT
Group:		System/Libraries
URL:		https://www.freedesktop.org/wiki/Software/libinput/
Source0:        https://gitlab.freedesktop.org/libinput/libinput/-/archive/%{version}/libinput-%{version}.tar.bz2

BuildRequires:  meson
BuildRequires:	pkgconfig(libudev)
BuildRequires:  pkgconfig(mtdev) >= 1.1.0
BuildRequires:	pkgconfig(libevdev) >= 0.4
BuildRequires:  pkgconfig(libwacom) >= 0.20
BuildRequires:  pkgconfig(udev)
BuildRequires:  python3-devel
BuildRequires:  check-devel

%description
libinput is a library that handles input devices for display servers and other
applications that need to directly deal with input devices.

It provides device detection, device handling, input device event
processing and abstraction so minimize the amount of custom input
code the user of libinput need to provide the common set of
functionality that users expect.

%package -n %{lib_name}
Summary:	Libraries for libinput
Group:		System/Libraries
Requires:	libinput-udev

%description -n %{lib_name}
libinput is a library that handles input devices for display servers and other
applications that need to directly deal with input devices.

It provides device detection, device handling, input device event processing
and abstraction so minimize the amount of custom input code the user of
libinput need to provide the common set of functionality that users expect.


%package -n %{develname}
Summary:        Development files for %{name}
Group:		Development/X11
Provides:	%{name}-devel = %{version}-%{release}
Requires:	%{lib_name} = %{version}

%description -n %{develname}
The %{develname} package contains libraries and header files for
developing applications that use %{name}.

%package tools
Summary:	Tools for libinput
Group:		System/Base

%description tools
libinput is a library that handles input devices for display servers and other
applications that need to directly deal with input devices.

It provides device detection, device handling, input device event processing
and abstraction so minimize the amount of custom input code the user of
libinput need to provide the common set of functionality that users expect.

This package contains the libinput tools.

%package udev
Summary:	Tools for libinput
Group:		System/Base

%description udev
libinput is a library that handles input devices for display servers and
other applications that need to directly deal with input devices.

It provides device detection, device handling, input device event
processing and abstraction so minimize the amount of custom input
code the user of libinput need to provide the common set of
functionality that users expect.

This package contains the udev rules for libinput.

%package        test
Summary:        libinput integration test suite
Requires:       %{lib_name}%{?_isa} = %{version}-%{release}

%description    test
The %{name}-test package contains the libinput test suite. It is not
intended to be run by users.

%prep
%autosetup -p1

%build
%meson -Ddebug-gui=false \
       -Ddocumentation=false \
       -Dtests=true \
       -Dinstall-tests=true \

%meson_build

%install
%meson_install

# for temporary local device quirks
mkdir -p %{buildroot}%{_sysconfdir}/libinput/

%files tools
%{_bindir}/*
%dir %{_libexecdir}/libinput/
%{_libexecdir}/libinput/libinput-debug-events
%{_libexecdir}/libinput/libinput-list-devices
%{_mandir}/man1/libinput.1*
%dir %{_datadir}/zsh
%dir %{_datadir}/zsh/site-functions
%{_datadir}/zsh/site-functions/*
%{_mandir}/man1/libinput-list-devices.1*
%{_mandir}/man1/libinput-debug-events.1*
%{_libexecdir}/libinput/libinput-analyze
%{_libexecdir}/libinput/libinput-analyze-per-slot-delta
%{_libexecdir}/libinput/libinput-analyze-recording
%{_libexecdir}/libinput/libinput-analyze-touch-down-state
%{_libexecdir}/libinput/libinput-debug-tablet
%{_libexecdir}/libinput/libinput-list-kernel-devices
%{_libexecdir}/libinput/libinput-measure
%{_libexecdir}/libinput/libinput-measure-fuzz
%{_libexecdir}/libinput/libinput-measure-touchpad-tap
%{_libexecdir}/libinput/libinput-measure-touchpad-pressure
%{_libexecdir}/libinput/libinput-measure-touchpad-size
%{_libexecdir}/libinput/libinput-measure-touch-size
%{_libexecdir}/libinput/libinput-quirks
%{_libexecdir}/libinput/libinput-record
%{_libexecdir}/libinput/libinput-replay
%{_mandir}/man1/libinput-analyze.1*
%{_mandir}/man1/libinput-analyze-per-slot-delta.1*
%{_mandir}/man1/libinput-analyze-recording.1*
%{_mandir}/man1/libinput-analyze-touch-down-state.1*
%{_mandir}/man1/libinput-debug-tablet.1*
%{_mandir}/man1/libinput-list-kernel-devices.1*
%{_mandir}/man1/libinput-measure.1*
%{_mandir}/man1/libinput-measure-fuzz.1*
%{_mandir}/man1/libinput-measure-touchpad-tap.1*
%{_mandir}/man1/libinput-measure-touch-size.1*
%{_mandir}/man1/libinput-measure-touchpad-pressure.1*
%{_mandir}/man1/libinput-measure-touchpad-size.1*
%{_mandir}/man1/libinput-quirks.1*
%{_mandir}/man1/libinput-quirks-list.1*
%{_mandir}/man1/libinput-quirks-validate.1*
%{_mandir}/man1/libinput-record.1*
%{_mandir}/man1/libinput-replay.1*

%files udev
%dir %{_sysconfdir}/libinput/
%{_udevrulesdir}/*
/usr/lib/udev/libinput-device-group
/usr/lib/udev/libinput-fuzz-extract
/usr/lib/udev/libinput-fuzz-to-zero
%{_datadir}/libinput/*.quirks

%files -n %{lib_name}
%{_libdir}/*.so.%{lib_major}{,.*}

%files -n %{develname}
%doc README.md COPYING
%{_includedir}/libinput.h
%{_libdir}/libinput.so
%{_libdir}/pkgconfig/libinput.pc

%files test
%{_libexecdir}/libinput/libinput-test
%{_libexecdir}/libinput/libinput-test-suite
%{_libexecdir}/libinput/libinput-test-utils
%{_mandir}/man1/libinput-test.1*
%{_mandir}/man1/libinput-test-suite.1*


%changelog
* Fri Jun 02 2023 wally <wally> 1.23.0-2.mga9
+ Revision: 1960530
- create and provide /etc/libinput/ with libinput-udev for temporary local device quirks

* Sat Apr 29 2023 squidf <squidf> 1.23.0-1.mga9
+ Revision: 1955371
- New version: 1.23.0

* Fri Jan 20 2023 luigiwalser <luigiwalser> 1.22.1-1.mga9
+ Revision: 1934536
- 1.22.1

* Sun Nov 20 2022 tv <tv> 1.22.0-1.mga9
+ Revision: 1909496
- libinput 1.22
- libinput 1.21

* Thu Apr 21 2022 ns80 <ns80> 1.20.1-1.mga9
+ Revision: 1852380
- new version 1.20.1 for CVE-2022-1215 (mga#30308)

* Sat Apr 02 2022 umeabot <umeabot> 1.20.0-2.mga9
+ Revision: 1840617
- Mageia 9 Mass Rebuild

* Sat Feb 19 2022 tmb <tmb> 1.20.0-1.mga9
+ Revision: 1781478
- update to 1.20.0

* Wed Feb 16 2022 tv <tv> 1.19.901-1.mga9
+ Revision: 1777984
- libinput 1.20rc1

* Mon Dec 13 2021 tv <tv> 1.19.3-1.mga9
+ Revision: 1761916
- libinput 1.19.3

* Mon Oct 25 2021 luigiwalser <luigiwalser> 1.19.2-1.mga9
+ Revision: 1752897
- 1.19.2

* Mon Oct 04 2021 luigiwalser <luigiwalser> 1.19.1-1.mga9
+ Revision: 1749426
- 1.19.1

* Tue Sep 14 2021 tv <tv> 1.19.0-1.mga9
+ Revision: 1745465
- 1.19.0

* Thu Aug 05 2021 luigiwalser <luigiwalser> 1.18.1-1.mga9
+ Revision: 1739628
- 1.18.1
- remove upstream patch

* Mon Jun 21 2021 tv <tv> 1.18.0-2.mga9
+ Revision: 1731602
- Add quirk for the Huawai Matebook 2020 (#1972370)

* Thu Jun 03 2021 tv <tv> 1.18.0-1.mga9
+ Revision: 1729450
- libinput 1.18.0

* Mon Mar 29 2021 tv <tv> 1.17.1-1.mga9
+ Revision: 1711735
- libinput 1.17.1

* Sat Feb 27 2021 tv <tv> 1.17.0-1.mga9
+ Revision: 1693073
- 1.17.0

* Fri Nov 27 2020 tv <tv> 1.16.4-1.mga8
+ Revision: 1649726
- 1.16.4

* Tue Nov 03 2020 tv <tv> 1.16.3-1.mga8
+ Revision: 1642181
- 1.16.3

* Fri Aug 21 2020 luigiwalser <luigiwalser> 1.16.1-1.mga8
+ Revision: 1617753
- 1.16.1

* Mon Aug 03 2020 tv <tv> 1.16.0-1.mga8
+ Revision: 1610734
- 1.16.0

* Sat Aug 01 2020 tv <tv> 1.15.902-1.mga8
+ Revision: 1610264
- 1.16rc2

* Wed Jul 15 2020 tv <tv> 1.15.901-1.mga8
+ Revision: 1606407
- 1.16rc1
- do not package libinput-test-suite twice

* Sun Jun 21 2020 tv <tv> 1.15.6-1.mga8
+ Revision: 1598330
- 1.15.6

* Sat Apr 11 2020 tv <tv> 1.15.5-1.mga8
+ Revision: 1566445
- 1.15.5

* Wed Mar 18 2020 tv <tv> 1.15.4-1.mga8
+ Revision: 1557754
- 1.15.4

* Fri Mar 13 2020 tv <tv> 1.15.3-1.mga8
+ Revision: 1556134
- new release
- fix libinput record's dmi modalias recording

* Tue Feb 25 2020 luigiwalser <luigiwalser> 1.15.2-1.mga8
+ Revision: 1550294
- 1.15.2

* Tue Feb 18 2020 umeabot <umeabot> 1.15.0-2.mga8
+ Revision: 1541996
- Mageia 8 Mass Rebuild

* Fri Jan 03 2020 tv <tv> 1.15.0-1.mga8
+ Revision: 1475867
- new release

* Sun Nov 03 2019 tv <tv> 1.14.3-1.mga8
+ Revision: 1457478
- 1.14.3

* Thu Aug 29 2019 tv <tv> 1.14.1-1.mga8
+ Revision: 1435041
- libinput 1.14.1

* Thu Aug 08 2019 tv <tv> 1.14.0-1.mga8
+ Revision: 1428175
- new release

* Mon Jul 22 2019 tv <tv> 1.13.901-1.mga8
+ Revision: 1423479
- 1.14 RC1

* Sat Jun 29 2019 tv <tv> 1.13.4-2.mga8
+ Revision: 1416121
- submit to core/release

* Sat Jun 29 2019 tv <tv> 1.13.4-1.mga8
+ Revision: 1416119
- new release

* Fri May 10 2019 tv <tv> 1.13.2-1.mga7
+ Revision: 1397117
- new release

* Wed Apr 17 2019 umeabot <umeabot> 1.13.1-3.mga7
+ Revision: 1392758
- Rebuild with meson 0.50.1

* Sun Apr 14 2019 pterjan <pterjan> 1.13.1-2.mga7
+ Revision: 1389922
- Fix dependency from -test to the lib package

* Wed Apr 10 2019 tv <tv> 1.13.1-1.mga7
+ Revision: 1387964
- 1.13.1

* Fri Mar 29 2019 tv <tv> 1.13.0-1.mga7
+ Revision: 1381061
- 1.13.0
- 1.13.0

* Thu Mar 21 2019 tv <tv> 1.12.902-1.mga7
+ Revision: 1379413
- new release

* Thu Mar 14 2019 tv <tv> 1.12.901-1.mga7
+ Revision: 1376452
- 1.13 RC1

* Thu Feb 14 2019 tv <tv> 1.12.6-2.mga7
+ Revision: 1367099
- Don't update the hwdb on install, we don't have any hwdb files anymore

* Mon Jan 21 2019 tv <tv> 1.12.6-1.mga7
+ Revision: 1358788
- new release

* Tue Jan 08 2019 tv <tv> 1.12.5-1.mga7
+ Revision: 1351904
- new release

* Tue Dec 18 2018 tv <tv> 1.12.4-1.mga7
+ Revision: 1342550
- 1.12.4

* Wed Nov 07 2018 tv <tv> 1.12.3-1.mga7
+ Revision: 1328777
- new release

* Wed Oct 24 2018 tv <tv> 1.12.2-1.mga7
+ Revision: 1324941
- 1.12.2

* Wed Oct 03 2018 tv <tv> 1.12.1-1.mga7
+ Revision: 1317215
- libinput 1.12.1

* Tue Sep 11 2018 tv <tv> 1.12.0-1.mga7
+ Revision: 1258296
- libinput 1.12

* Tue Sep 04 2018 tv <tv> 1.11.903-1.mga7
+ Revision: 1256965
- libinput 1.12rc3

* Tue Aug 14 2018 tv <tv> 1.11.902-1.mga7
+ Revision: 1251484
- libinput 1.12rc2

* Wed Aug 01 2018 tv <tv> 1.11.901-1.mga7
+ Revision: 1246487
- libinput 1.12rc1

* Tue Jul 03 2018 tv <tv> 1.11.2-1.mga7
+ Revision: 1241456
- new release

* Wed Jun 20 2018 tv <tv> 1.11.1-2.mga7
+ Revision: 1238315
- Fix segfault in libinput list-devices

* Tue Jun 19 2018 tv <tv> 1.11.1-1.mga7
+ Revision: 1238132
- new release

* Tue Jun 05 2018 tv <tv> 1.11.0-1.mga7
+ Revision: 1234680
- 1.11.0

* Wed May 30 2018 tv <tv> 1.10.902-1.mga7
+ Revision: 1233105
- libinput 1.11 rc2
- fix license

* Tue May 22 2018 tv <tv> 1.10.901-1.mga7
+ Revision: 1231454
- libinput 1.11 rc1 (dropping libinput-* wrappers)

* Thu May 17 2018 tv <tv> 1.10.7-1.mga7
+ Revision: 1230001
- libinput 1.10.7

* Mon May 14 2018 tv <tv> 1.10.6-2.mga7
+ Revision: 1229572
- Fix palm threshold on MacBookPro5,5 (rhbz#1575260)

* Tue May 01 2018 tv <tv> 1.10.6-1.mga7
+ Revision: 1224227
- libinput 1.10.6
- Fix the T460s halting cursor problem (rhbz#1572394)

* Thu Apr 19 2018 tv <tv> 1.10.5-1.mga7
+ Revision: 1220038
- libinput 1.10.5
- Disable ABS_MT_TOOL_PALM on the Lenovo Carbon X1 6th (rhbz#1565692)

* Mon Apr 09 2018 tv <tv> 1.10.4-1.mga7
+ Revision: 1216545
- new release

* Wed Mar 14 2018 tv <tv> 1.10.3-1.mga7
+ Revision: 1209438
- new release

* Mon Mar 12 2018 tv <tv> 1.10.2-2.mga7
+ Revision: 1208658
- Fix occasional crashes on gestures when libinput loses track of hovering
  fake fingers

* Thu Mar 08 2018 tv <tv> 1.10.2-1.mga7
+ Revision: 1207432
- libinput 1.10.2

* Sat Mar 03 2018 tv <tv> 1.10.1-1.mga7
+ Revision: 1206360
- new release

* Tue Feb 13 2018 tv <tv> 1.10.0-1.mga7
+ Revision: 1200774
- libinput 1.10
- Fix crasher due to missing devnode after resume (rhbz#1536633)

* Wed Feb 07 2018 tv <tv> 1.9.902-1.mga7
+ Revision: 1199441
- 1.10rc2

* Mon Feb 05 2018 tv <tv> 1.9.901-2.mga7
+ Revision: 1199114
- Fix crasher on first event from tablets not supported by libwacom
  (rhbz#1535755)

* Tue Jan 23 2018 tv <tv> 1.9.901-1.mga7
+ Revision: 1196567
- 1.10rc1

* Fri Dec 15 2017 tv <tv> 1.9.4-1.mga7
+ Revision: 1182729
- new release

* Sat Dec 09 2017 tv <tv> 1.9.3-2.mga7
+ Revision: 1181795
- Immediately post key events, don't wait for EV_SYN

* Tue Nov 28 2017 tv <tv> 1.9.3-1.mga7
+ Revision: 1180115
- new release

* Fri Nov 17 2017 tv <tv> 1.9.2-1.mga7
+ Revision: 1177640
- new release
- Mark the Lenovo Compact Keyboard as external (rhbz#1510814)

* Mon Oct 30 2017 tv <tv> 1.9.1-1.mga7
+ Revision: 1174889
- new release

* Thu Oct 19 2017 tv <tv> 1.9.0-1.mga7
+ Revision: 1172691
- new release

* Tue Oct 10 2017 tv <tv> 1.8.902-1.mga7
+ Revision: 1170778
- 1.9 RC2

* Wed Sep 27 2017 tv <tv> 1.8.901-1.mga7
+ Revision: 1160244
- new release

* Thu Sep 07 2017 tv <tv> 1.8.2-1.mga7
+ Revision: 1151784
- new release

* Wed Sep 06 2017 tv <tv> 1.8.1-2.mga7
+ Revision: 1151617
- Don't try pinching when the finger number exceeds available slots
- Don't resume a disabled touchpad after a lid switch open (rhbz#1448962)

* Fri Jul 21 2017 tv <tv> 1.8.1-1.mga7
+ Revision: 1125821
- new release

* Tue Jul 18 2017 tv <tv> 1.8.0-1.mga7
+ Revision: 1124748
- switch to meson

* Sat Jul 08 2017 tv <tv> 1.8.0-0.1.mga7
+ Revision: 1109548
- new release

* Wed Jun 28 2017 tv <tv> 1.7.3-1.mga6
+ Revision: 1108611
- New release
- Ignore taps in the palm detection area even in software buttons (rhbz#1415796)
- Fix a crash when we have multiple keyboard event listeners for the lid switch
  and when shutting down a touchpad lid listener (#1440927)

* Wed May 10 2017 tv <tv> 1.7.2-1.mga6
+ Revision: 1100071
- New release
- Ignore taps in the palm detection area even in software buttons (rhbz#1415796)
- Fix a crash when we have multiple keyboard event listeners for the lid switch
  and when shutting down a touchpad lid listener (#1440927)

* Thu Mar 23 2017 tv <tv> 1.7.0-1.mga6
+ Revision: 1094598
- new release

* Mon Mar 13 2017 tv <tv> 1.6.902-1.mga6
+ Revision: 1092332
- 1.7rc2
- 1.7 RC1

* Tue Feb 14 2017 tv <tv> 1.6.1-1.mga6
+ Revision: 1086167
- new version

* Fri Jan 20 2017 tv <tv> 1.6.0-1.mga6
+ Revision: 1082502
- new release

* Thu Jan 19 2017 tv <tv> 1.5.902-1.mga6
+ Revision: 1082446
- 1.6rc2

* Fri Dec 09 2016 tv <tv> 1.5.3-1.mga6
+ Revision: 1073775
- new release

* Fri Nov 25 2016 tv <tv> 1.5.2-1.mga6
+ Revision: 1070129
- new release

* Tue Nov 15 2016 tv <tv> 1.5.1-1.mga6
+ Revision: 1067480
- new release

* Wed Sep 14 2016 tv <tv> 1.5.0-1.mga6
+ Revision: 1052945
- new version

* Wed Aug 31 2016 tv <tv> 1.4.2-1.mga6
+ Revision: 1049652
- new release

* Fri Aug 05 2016 tv <tv> 1.4.1-1.mga6
+ Revision: 1044662
- new release

* Wed Jul 20 2016 tmb <tmb> 1.4.0-1.mga6
+ Revision: 1042911
- 1.4.0 (improved tablet and touchpad support)

* Fri Jun 24 2016 tv <tv> 1.3.3-1.mga6
+ Revision: 1037465
- drop now unnecessary patch
- new release

* Thu Jun 16 2016 tv <tv> 1.3.2-1.mga6
+ Revision: 1021802
- new release

* Wed Jun 01 2016 tv <tv> 1.3.1-3.mga6
+ Revision: 1019673
- make the %%post usefull by putting it on the right subpkg

* Tue May 31 2016 tv <tv> 1.3.1-2.mga6
+ Revision: 1019527
- update the global compiled file /etc/udev/hwdb.bin

* Mon May 30 2016 tv <tv> 1.3.1-1.mga6
+ Revision: 1019373
- new release

* Fri May 20 2016 tv <tv> 1.3.0-3.mga6
+ Revision: 1017091
- stop pointer jitter on the Dell E5420, E530 and Lenovo Yoga 2

* Thu May 19 2016 tv <tv> 1.3.0-2.mga6
+ Revision: 1016886
- Disable negative pressure transition on non-synaptics pads to avoid
  jerky movement (rhbz#1335249)

* Tue May 10 2016 tv <tv> 1.3.0-1.mga6
+ Revision: 1011934
- new release

* Wed May 04 2016 tv <tv> 1.2.903-1.mga6
+ Revision: 1009360
- 1.3 RC3

* Fri Apr 22 2016 tv <tv> 1.2.902-1.mga6
+ Revision: 1004876
- use %%make_install
- fix devel description
- 1.3 RC2

* Mon Mar 21 2016 fwang <fwang> 1.2.2-1.mga6
+ Revision: 993464
- 1.2.2

* Wed Feb 24 2016 tv <tv> 1.2.0-1.mga6
+ Revision: 978594
- new release

* Wed Feb 17 2016 tv <tv> 1.1.902-1.mga6
+ Revision: 963120
- 1.1.902

* Fri Jan 29 2016 tv <tv> 1.1.901-1.mga6
+ Revision: 928639
- BR pkgconfig(libwacom)
- new release
- new release

* Mon Jan 25 2016 tv <tv> 1.1.5-1.mga6
+ Revision: 927415
- new release

* Mon Oct 26 2015 tv <tv> 1.1.0-1.mga6
+ Revision: 895612
- new release

* Wed Oct 21 2015 tv <tv> 1.0.2-1.mga6
+ Revision: 893799
- new release

* Fri Sep 04 2015 tv <tv> 1.0.1-1.mga6
+ Revision: 872692
- new release

* Wed Aug 26 2015 tv <tv> 1.0.0-1.mga6
+ Revision: 869453
- new release

* Tue Aug 04 2015 tv <tv> 0.21.0-1.mga6
+ Revision: 861073
- adjust filelist
- new release

* Wed Jul 22 2015 ovitters <ovitters> 0.20.0-1.mga6
+ Revision: 856172
- new version 0.20.0

* Wed Jun 24 2015 tv <tv> 0.18.0-3.mga6
+ Revision: 842419
- adjust file list
- fix udev rules location

* Wed Jun 24 2015 tv <tv> 0.18.0-2.mga6
+ Revision: 842319
- adjust file list
- prevent udev rules to land in lib64

* Wed Jun 24 2015 tv <tv> 0.18.0-1.mga6
+ Revision: 841855
- new release

* Sat Jun 20 2015 tv <tv> 0.17.0-1.mga6
+ Revision: 835787
- new release

* Sat Jun 20 2015 tv <tv> 0.16.0-1.mga6
+ Revision: 835778
- new release

* Tue Feb 17 2015 wally <wally> 0.6.0-4.mga5
+ Revision: 815319
- fix summary and rpm group for devel pkg

* Wed Oct 15 2014 umeabot <umeabot> 0.6.0-3.mga5
+ Revision: 745122
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 0.6.0-2.mga5
+ Revision: 681538
- Mageia 5 Mass Rebuild

* Sat Sep 13 2014 tv <tv> 0.6.0-1.mga5
+ Revision: 674970
- new release

* Wed Jul 23 2014 tv <tv> 0.5.0-1.mga5
+ Revision: 655915
- new release

* Thu Jun 26 2014 tv <tv> 0.4.0-1.mga5
+ Revision: 639915
- bump major
- new release

* Mon May 26 2014 tv <tv> 0.2.0-1.mga5
+ Revision: 626565
- new release
+ fwang <fwang>
- fix summary

* Tue Mar 04 2014 fwang <fwang> 0.1.0-1.mga5
+ Revision: 599299
- imported package libinput

